quantizationtools.QSchema
=========================

.. abjad-lineage:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema

.. autoclass:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.item_class
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.items
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.search_tree
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.target_class
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.target_item_class
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.tempo
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__call__
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__eq__
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__getitem__
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__ne__
      ~abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.item_class
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.items
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.target_class
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.target_item_class
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.tempo
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__getitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__repr__
   :noindex:
